svn commit: r1090153 [12/20] - in /ofbiz/branches/jackrabbit20100709: ./ applications/accounting/config/ applications/accounting/script/org/ofbiz/accounting/agreement/ applications/accounting/src/org/ofbiz/accounting/invoice/ applications/accounting/sr...

Previous Topic Next Topic
 
classic Classic list List threaded Threaded
1 message Options
Reply | Threaded
Open this post in threaded view
|

svn commit: r1090153 [12/20] - in /ofbiz/branches/jackrabbit20100709: ./ applications/accounting/config/ applications/accounting/script/org/ofbiz/accounting/agreement/ applications/accounting/src/org/ofbiz/accounting/invoice/ applications/accounting/sr...

sascharodekamp
Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.blind.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.blind.js?rev=1090153&r1=1090152&r2=1090153&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.blind.js (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.blind.js Fri Apr  8 08:07:00 2011
@@ -1,7 +1,7 @@
 /*
- * jQuery UI Effects Blind 1.8.6
+ * jQuery UI Effects Blind 1.8.11
  *
- * Copyright 2010, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
  * http://jquery.org/license
  *
@@ -17,7 +17,7 @@ $.effects.blind = function(o) {
  return this.queue(function() {
 
  // Create element
- var el = $(this), props = ['position','top','left'];
+ var el = $(this), props = ['position','top','bottom','left','right'];
 
  // Set options
  var mode = $.effects.setMode(el, o.options.mode || 'hide'); // Set Mode

Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.bounce.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.bounce.js?rev=1090153&r1=1090152&r2=1090153&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.bounce.js (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.bounce.js Fri Apr  8 08:07:00 2011
@@ -1,7 +1,7 @@
 /*
- * jQuery UI Effects Bounce 1.8.6
+ * jQuery UI Effects Bounce 1.8.11
  *
- * Copyright 2010, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
  * http://jquery.org/license
  *
@@ -17,7 +17,7 @@ $.effects.bounce = function(o) {
  return this.queue(function() {
 
  // Create element
- var el = $(this), props = ['position','top','left'];
+ var el = $(this), props = ['position','top','bottom','left','right'];
 
  // Set options
  var mode = $.effects.setMode(el, o.options.mode || 'effect'); // Set Mode

Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.clip.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.clip.js?rev=1090153&r1=1090152&r2=1090153&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.clip.js (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.clip.js Fri Apr  8 08:07:00 2011
@@ -1,7 +1,7 @@
 /*
- * jQuery UI Effects Clip 1.8.6
+ * jQuery UI Effects Clip 1.8.11
  *
- * Copyright 2010, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
  * http://jquery.org/license
  *
@@ -17,7 +17,7 @@ $.effects.clip = function(o) {
  return this.queue(function() {
 
  // Create element
- var el = $(this), props = ['position','top','left','height','width'];
+ var el = $(this), props = ['position','top','bottom','left','right','height','width'];
 
  // Set options
  var mode = $.effects.setMode(el, o.options.mode || 'hide'); // Set Mode

Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.core.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.core.js?rev=1090153&r1=1090152&r2=1090153&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.drop.js (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.drop.js Fri Apr  8 08:07:00 2011
@@ -1,7 +1,7 @@
 /*
- * jQuery UI Effects Drop 1.8.6
+ * jQuery UI Effects Drop 1.8.11
  *
- * Copyright 2010, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
  * http://jquery.org/license
  *
@@ -17,7 +17,7 @@ $.effects.drop = function(o) {
  return this.queue(function() {
 
  // Create element
- var el = $(this), props = ['position','top','left','opacity'];
+ var el = $(this), props = ['position','top','bottom','left','right','opacity'];
 
  // Set options
  var mode = $.effects.setMode(el, o.options.mode || 'hide'); // Set Mode

Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.explode.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.explode.js?rev=1090153&r1=1090152&r2=1090153&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.explode.js (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.explode.js Fri Apr  8 08:07:00 2011
@@ -1,7 +1,7 @@
 /*
- * jQuery UI Effects Explode 1.8.6
+ * jQuery UI Effects Explode 1.8.11
  *
- * Copyright 2010, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
  * http://jquery.org/license
  *

Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.fade.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.fade.js?rev=1090153&r1=1090152&r2=1090153&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.fade.js (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.fade.js Fri Apr  8 08:07:00 2011
@@ -1,7 +1,7 @@
 /*
- * jQuery UI Effects Fade 1.8.6
+ * jQuery UI Effects Fade 1.8.11
  *
- * Copyright 2010, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
  * http://jquery.org/license
  *

Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.fold.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.fold.js?rev=1090153&r1=1090152&r2=1090153&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.fold.js (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.fold.js Fri Apr  8 08:07:00 2011
@@ -1,7 +1,7 @@
 /*
- * jQuery UI Effects Fold 1.8.6
+ * jQuery UI Effects Fold 1.8.11
  *
- * Copyright 2010, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
  * http://jquery.org/license
  *
@@ -17,7 +17,7 @@ $.effects.fold = function(o) {
  return this.queue(function() {
 
  // Create element
- var el = $(this), props = ['position','top','left'];
+ var el = $(this), props = ['position','top','bottom','left','right'];
 
  // Set options
  var mode = $.effects.setMode(el, o.options.mode || 'hide'); // Set Mode

Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.highlight.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.highlight.js?rev=1090153&r1=1090152&r2=1090153&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.highlight.js (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.highlight.js Fri Apr  8 08:07:00 2011
@@ -1,7 +1,7 @@
 /*
- * jQuery UI Effects Highlight 1.8.6
+ * jQuery UI Effects Highlight 1.8.11
  *
- * Copyright 2010, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
  * http://jquery.org/license
  *

Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.pulsate.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.pulsate.js?rev=1090153&r1=1090152&r2=1090153&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.pulsate.js (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.pulsate.js Fri Apr  8 08:07:00 2011
@@ -1,7 +1,7 @@
 /*
- * jQuery UI Effects Pulsate 1.8.6
+ * jQuery UI Effects Pulsate 1.8.11
  *
- * Copyright 2010, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
  * http://jquery.org/license
  *

Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.scale.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.scale.js?rev=1090153&r1=1090152&r2=1090153&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.scale.js (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.scale.js Fri Apr  8 08:07:00 2011
@@ -1,7 +1,7 @@
 /*
- * jQuery UI Effects Scale 1.8.6
+ * jQuery UI Effects Scale 1.8.11
  *
- * Copyright 2010, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
  * http://jquery.org/license
  *
@@ -84,8 +84,8 @@ $.effects.size = function(o) {
  return this.queue(function() {
 
  // Create element
- var el = $(this), props = ['position','top','left','width','height','overflow','opacity'];
- var props1 = ['position','top','left','overflow','opacity']; // Always restore
+ var el = $(this), props = ['position','top','bottom','left','right','width','height','overflow','opacity'];
+ var props1 = ['position','top','bottom','left','right','overflow','opacity']; // Always restore
  var props2 = ['width','height','overflow']; // Copy for children
  var cProps = ['fontSize'];
  var vProps = ['borderTopWidth', 'borderBottomWidth', 'paddingTop', 'paddingBottom'];

Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.shake.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.shake.js?rev=1090153&r1=1090152&r2=1090153&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.shake.js (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.shake.js Fri Apr  8 08:07:00 2011
@@ -1,7 +1,7 @@
 /*
- * jQuery UI Effects Shake 1.8.6
+ * jQuery UI Effects Shake 1.8.11
  *
- * Copyright 2010, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
  * http://jquery.org/license
  *
@@ -17,7 +17,7 @@ $.effects.shake = function(o) {
  return this.queue(function() {
 
  // Create element
- var el = $(this), props = ['position','top','left'];
+ var el = $(this), props = ['position','top','bottom','left','right'];
 
  // Set options
  var mode = $.effects.setMode(el, o.options.mode || 'effect'); // Set Mode

Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.slide.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.slide.js?rev=1090153&r1=1090152&r2=1090153&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.slide.js (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.slide.js Fri Apr  8 08:07:00 2011
@@ -1,7 +1,7 @@
 /*
- * jQuery UI Effects Slide 1.8.6
+ * jQuery UI Effects Slide 1.8.11
  *
- * Copyright 2010, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
  * http://jquery.org/license
  *
@@ -17,7 +17,7 @@ $.effects.slide = function(o) {
  return this.queue(function() {
 
  // Create element
- var el = $(this), props = ['position','top','left'];
+ var el = $(this), props = ['position','top','bottom','left','right'];
 
  // Set options
  var mode = $.effects.setMode(el, o.options.mode || 'show'); // Set Mode
@@ -29,7 +29,7 @@ $.effects.slide = function(o) {
  var ref = (direction == 'up' || direction == 'down') ? 'top' : 'left';
  var motion = (direction == 'up' || direction == 'left') ? 'pos' : 'neg';
  var distance = o.options.distance || (ref == 'top' ? el.outerHeight({margin:true}) : el.outerWidth({margin:true}));
- if (mode == 'show') el.css(ref, motion == 'pos' ? -distance : distance); // Shift
+ if (mode == 'show') el.css(ref, motion == 'pos' ? (isNaN(distance) ? "-" + distance : -distance) : distance); // Shift
 
  // Animation
  var animation = {};

Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.transfer.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.transfer.js?rev=1090153&r1=1090152&r2=1090153&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.transfer.js (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.transfer.js Fri Apr  8 08:07:00 2011
@@ -1,7 +1,7 @@
 /*
- * jQuery UI Effects Transfer 1.8.6
+ * jQuery UI Effects Transfer 1.8.11
  *
- * Copyright 2010, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
  * http://jquery.org/license
  *

Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.accordion.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.accordion.js?rev=1090153&r1=1090152&r2=1090153&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.autocomplete.js (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.autocomplete.js Fri Apr  8 08:07:00 2011
@@ -1,7 +1,7 @@
 /*
- * jQuery UI Autocomplete 1.8.6
+ * jQuery UI Autocomplete 1.8.11
  *
- * Copyright 2010, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
  * http://jquery.org/license
  *
@@ -14,9 +14,13 @@
  */
 (function( $, undefined ) {
 
+// used to prevent race conditions with remote data sources
+var requestIndex = 0;
+
 $.widget( "ui.autocomplete", {
  options: {
  appendTo: "body",
+ autoFocus: false,
  delay: 300,
  minLength: 1,
  position: {
@@ -26,6 +30,9 @@ $.widget( "ui.autocomplete", {
  },
  source: null
  },
+
+ pending: 0,
+
  _create: function() {
  var self = this,
  doc = this.element[ 0 ].ownerDocument,
@@ -177,6 +184,7 @@ $.widget( "ui.autocomplete", {
  // term synchronously and asynchronously :-(
  setTimeout(function() {
  self.previous = previous;
+ self.selectedItem = item;
  }, 1);
  }
 
@@ -228,6 +236,9 @@ $.widget( "ui.autocomplete", {
  if ( key === "appendTo" ) {
  this.menu.element.appendTo( $( value || "body", this.element[0].ownerDocument )[0] )
  }
+ if ( key === "disabled" && value && this.xhr ) {
+ this.xhr.abort();
+ }
  },
 
  _initSource: function() {
@@ -242,14 +253,24 @@ $.widget( "ui.autocomplete", {
  } else if ( typeof this.options.source === "string" ) {
  url = this.options.source;
  this.source = function( request, response ) {
- if (self.xhr) {
+ if ( self.xhr ) {
  self.xhr.abort();
  }
- self.xhr = $.getJSON( url, request, function( data, status, xhr ) {
- if ( xhr === self.xhr ) {
- response( data );
+ self.xhr = $.ajax({
+ url: url,
+ data: request,
+ dataType: "json",
+ autocompleteRequest: ++requestIndex,
+ success: function( data, status ) {
+ if ( this.autocompleteRequest === requestIndex ) {
+ response( data );
+ }
+ },
+ error: function() {
+ if ( this.autocompleteRequest === requestIndex ) {
+ response( [] );
+ }
  }
- self.xhr = null;
  });
  };
  } else {
@@ -276,28 +297,32 @@ $.widget( "ui.autocomplete", {
  },
 
  _search: function( value ) {
+ this.pending++;
  this.element.addClass( "ui-autocomplete-loading" );
 
  this.source( { term: value }, this.response );
  },
 
  _response: function( content ) {
- if ( content && content.length ) {
+ if ( !this.options.disabled && content && content.length ) {
  content = this._normalize( content );
  this._suggest( content );
  this._trigger( "open" );
  } else {
  this.close();
  }
- this.element.removeClass( "ui-autocomplete-loading" );
+ this.pending--;
+ if ( !this.pending ) {
+ this.element.removeClass( "ui-autocomplete-loading" );
+ }
  },
 
  close: function( event ) {
  clearTimeout( this.closing );
  if ( this.menu.element.is(":visible") ) {
- this._trigger( "close", event );
  this.menu.element.hide();
  this.menu.deactivate();
+ this._trigger( "close", event );
  }
  },
 
@@ -334,11 +359,17 @@ $.widget( "ui.autocomplete", {
  // TODO refresh should check if the active item is still in the dom, removing the need for a manual deactivate
  this.menu.deactivate();
  this.menu.refresh();
- this.menu.element.show().position( $.extend({
+
+ // size and position menu
+ ul.show();
+ this._resizeMenu();
+ ul.position( $.extend({
  of: this.element
  }, this.options.position ));
 
- this._resizeMenu();
+ if ( this.options.autoFocus ) {
+ this.menu.next( new $.Event("mouseover") );
+ }
  },
 
  _resizeMenu: function() {

Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.button.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.button.js?rev=1090153&r1=1090152&r2=1090153&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.button.js (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.button.js Fri Apr  8 08:07:00 2011
@@ -1,7 +1,7 @@
 /*
- * jQuery UI Button 1.8.6
+ * jQuery UI Button 1.8.11
  *
- * Copyright 2010, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
  * http://jquery.org/license
  *
@@ -200,8 +200,16 @@ $.widget( "ui.button", {
  if ( this.type === "checkbox" || this.type === "radio" ) {
  // we don't search against the document in case the element
  // is disconnected from the DOM
- this.buttonElement = this.element.parents().last()
- .find( "label[for=" + this.element.attr("id") + "]" );
+ var ancestor = this.element.parents().filter(":last"),
+ labelSelector = "label[for=" + this.element.attr("id") + "]";
+ this.buttonElement = ancestor.find( labelSelector );
+ if ( !this.buttonElement.length ) {
+ ancestor = ancestor.length ? ancestor.siblings() : this.element.siblings();
+ this.buttonElement = ancestor.filter( labelSelector );
+ if ( !this.buttonElement.length ) {
+ this.buttonElement = ancestor.find( labelSelector );
+ }
+ }
  this.element.addClass( "ui-helper-hidden-accessible" );
 
  var checked = this.element.is( ":checked" );
@@ -290,31 +298,41 @@ $.widget( "ui.button", {
  .appendTo( buttonElement.empty() )
  .text(),
  icons = this.options.icons,
- multipleIcons = icons.primary && icons.secondary;
+ multipleIcons = icons.primary && icons.secondary,
+ buttonClasses = [];  
+
  if ( icons.primary || icons.secondary ) {
- buttonElement.addClass( "ui-button-text-icon" +
- ( multipleIcons ? "s" : ( icons.primary ? "-primary" : "-secondary" ) ) );
+ if ( this.options.text ) {
+ buttonClasses.push( "ui-button-text-icon" + ( multipleIcons ? "s" : ( icons.primary ? "-primary" : "-secondary" ) ) );
+ }
+
  if ( icons.primary ) {
  buttonElement.prepend( "<span class='ui-button-icon-primary ui-icon " + icons.primary + "'></span>" );
  }
+
  if ( icons.secondary ) {
  buttonElement.append( "<span class='ui-button-icon-secondary ui-icon " + icons.secondary + "'></span>" );
  }
+
  if ( !this.options.text ) {
- buttonElement
- .addClass( multipleIcons ? "ui-button-icons-only" : "ui-button-icon-only" )
- .removeClass( "ui-button-text-icons ui-button-text-icon-primary ui-button-text-icon-secondary" );
+ buttonClasses.push( multipleIcons ? "ui-button-icons-only" : "ui-button-icon-only" );
+
  if ( !this.hasTitle ) {
  buttonElement.attr( "title", buttonText );
  }
  }
  } else {
- buttonElement.addClass( "ui-button-text-only" );
+ buttonClasses.push( "ui-button-text-only" );
  }
+ buttonElement.addClass( buttonClasses.join( " " ) );
  }
 });
 
 $.widget( "ui.buttonset", {
+ options: {
+ items: ":button, :submit, :reset, :checkbox, :radio, a, :data(button)"
+ },
+
  _create: function() {
  this.element.addClass( "ui-buttonset" );
  },
@@ -332,7 +350,7 @@ $.widget( "ui.buttonset", {
  },
 
  refresh: function() {
- this.buttons = this.element.find( ":button, :submit, :reset, :checkbox, :radio, a, :data(button)" )
+ this.buttons = this.element.find( this.options.items )
  .filter( ":ui-button" )
  .button( "refresh" )
  .end()
@@ -343,13 +361,11 @@ $.widget( "ui.buttonset", {
  return $( this ).button( "widget" )[ 0 ];
  })
  .removeClass( "ui-corner-all ui-corner-left ui-corner-right" )
- .filter( ":visible" )
- .filter( ":first" )
- .addClass( "ui-corner-left" )
- .end()
- .filter( ":last" )
- .addClass( "ui-corner-right" )
- .end()
+ .filter( ":first" )
+ .addClass( "ui-corner-left" )
+ .end()
+ .filter( ":last" )
+ .addClass( "ui-corner-right" )
  .end()
  .end();
  },

Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.core.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.core.js?rev=1090153&r1=1090152&r2=1090153&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.core.js (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.core.js Fri Apr  8 08:07:00 2011
@@ -1,7 +1,7 @@
 /*!
- * jQuery UI 1.8.6
+ * jQuery UI 1.8.11
  *
- * Copyright 2010, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
  * http://jquery.org/license
  *
@@ -18,7 +18,7 @@ if ( $.ui.version ) {
 }
 
 $.extend( $.ui, {
- version: "1.8.6",
+ version: "1.8.11",
 
  keyCode: {
  ALT: 18,

Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.datepicker.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.datepicker.js?rev=1090153&r1=1090152&r2=1090153&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.mouse.js (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.mouse.js Fri Apr  8 08:07:00 2011
@@ -1,7 +1,7 @@
 /*!
- * jQuery UI Mouse 1.8.6
+ * jQuery UI Mouse 1.8.11
  *
- * Copyright 2010, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
  * http://jquery.org/license
  *
@@ -26,8 +26,8 @@ $.widget("ui.mouse", {
  return self._mouseDown(event);
  })
  .bind('click.'+this.widgetName, function(event) {
- if(self._preventClickEvent) {
- self._preventClickEvent = false;
+ if (true === $.data(event.target, self.widgetName + '.preventClickEvent')) {
+    $.removeData(event.target, self.widgetName + '.preventClickEvent');
  event.stopImmediatePropagation();
  return false;
  }
@@ -75,6 +75,11 @@ $.widget("ui.mouse", {
  }
  }
 
+ // Click event may never have fired (Gecko & Opera)
+ if (true === $.data(event.target, this.widgetName + '.preventClickEvent')) {
+ $.removeData(event.target, this.widgetName + '.preventClickEvent');
+ }
+
  // these delegates are required to keep context
  this._mouseMoveDelegate = function(event) {
  return self._mouseMove(event);
@@ -118,7 +123,11 @@ $.widget("ui.mouse", {
 
  if (this._mouseStarted) {
  this._mouseStarted = false;
- this._preventClickEvent = (event.target == this._mouseDownEvent.target);
+
+ if (event.target == this._mouseDownEvent.target) {
+    $.data(event.target, this.widgetName + '.preventClickEvent', true);
+ }
+
  this._mouseStop(event);
  }
 

Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.position.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.position.js?rev=1090153&r1=1090152&r2=1090153&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.position.js (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.position.js Fri Apr  8 08:07:00 2011
@@ -1,7 +1,7 @@
 /*
- * jQuery UI Position 1.8.6
+ * jQuery UI Position 1.8.11
  *
- * Copyright 2010, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
  * http://jquery.org/license
  *
@@ -83,7 +83,7 @@ $.fn.position = function( options ) {
 
  if ( options.at[0] === "right" ) {
  basePosition.left += targetWidth;
- } else if (options.at[0] === center ) {
+ } else if ( options.at[0] === center ) {
  basePosition.left += targetWidth / 2;
  }
 
@@ -103,9 +103,9 @@ $.fn.position = function( options ) {
  marginLeft = parseInt( $.curCSS( this, "marginLeft", true ) ) || 0,
  marginTop = parseInt( $.curCSS( this, "marginTop", true ) ) || 0,
  collisionWidth = elemWidth + marginLeft +
- parseInt( $.curCSS( this, "marginRight", true ) ) || 0,
+ ( parseInt( $.curCSS( this, "marginRight", true ) ) || 0 ),
  collisionHeight = elemHeight + marginTop +
- parseInt( $.curCSS( this, "marginBottom", true ) ) || 0,
+ ( parseInt( $.curCSS( this, "marginBottom", true ) ) || 0 ),
  position = $.extend( {}, basePosition ),
  collisionPosition;
 
@@ -122,8 +122,8 @@ $.fn.position = function( options ) {
  }
 
  // prevent fractions (see #5280)
- position.left = parseInt( position.left );
- position.top = parseInt( position.top );
+ position.left = Math.round( position.left );
+ position.top = Math.round( position.top );
 
  collisionPosition = {
  left: position.left - marginLeft,

Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.progressbar.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.progressbar.js?rev=1090153&r1=1090152&r2=1090153&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.widget.js (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.widget.js Fri Apr  8 08:07:00 2011
@@ -1,7 +1,7 @@
 /*!
- * jQuery UI Widget 1.8.6
+ * jQuery UI Widget 1.8.11
  *
- * Copyright 2010, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
  * http://jquery.org/license
  *

Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.blind.min.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.blind.min.js?rev=1090153&r1=1090152&r2=1090153&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.blind.min.js (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.blind.min.js Fri Apr  8 08:07:00 2011
@@ -1,7 +1,7 @@
 /*
- * jQuery UI Effects Blind 1.8.6
+ * jQuery UI Effects Blind 1.8.11
  *
- * Copyright 2010, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
  * http://jquery.org/license
  *
@@ -10,5 +10,5 @@
  * Depends:
  * jquery.effects.core.js
  */
-(function(b){b.effects.blind=function(c){return this.queue(function(){var a=b(this),g=["position","top","left"],f=b.effects.setMode(a,c.options.mode||"hide"),d=c.options.direction||"vertical";b.effects.save(a,g);a.show();var e=b.effects.createWrapper(a).css({overflow:"hidden"}),h=d=="vertical"?"height":"width";d=d=="vertical"?e.height():e.width();f=="show"&&e.css(h,0);var i={};i[h]=f=="show"?d:0;e.animate(i,c.duration,c.options.easing,function(){f=="hide"&&a.hide();b.effects.restore(a,g);b.effects.removeWrapper(a);
-c.callback&&c.callback.apply(a[0],arguments);a.dequeue()})})}})(jQuery);
+(function(b){b.effects.blind=function(c){return this.queue(function(){var a=b(this),g=["position","top","bottom","left","right"],f=b.effects.setMode(a,c.options.mode||"hide"),d=c.options.direction||"vertical";b.effects.save(a,g);a.show();var e=b.effects.createWrapper(a).css({overflow:"hidden"}),h=d=="vertical"?"height":"width";d=d=="vertical"?e.height():e.width();f=="show"&&e.css(h,0);var i={};i[h]=f=="show"?d:0;e.animate(i,c.duration,c.options.easing,function(){f=="hide"&&a.hide();b.effects.restore(a,
+g);b.effects.removeWrapper(a);c.callback&&c.callback.apply(a[0],arguments);a.dequeue()})})}})(jQuery);

Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.bounce.min.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.bounce.min.js?rev=1090153&r1=1090152&r2=1090153&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.bounce.min.js (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.bounce.min.js Fri Apr  8 08:07:00 2011
@@ -1,7 +1,7 @@
 /*
- * jQuery UI Effects Bounce 1.8.6
+ * jQuery UI Effects Bounce 1.8.11
  *
- * Copyright 2010, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
  * http://jquery.org/license
  *
@@ -10,6 +10,6 @@
  * Depends:
  * jquery.effects.core.js
  */
-(function(e){e.effects.bounce=function(b){return this.queue(function(){var a=e(this),l=["position","top","left"],h=e.effects.setMode(a,b.options.mode||"effect"),d=b.options.direction||"up",c=b.options.distance||20,m=b.options.times||5,i=b.duration||250;/show|hide/.test(h)&&l.push("opacity");e.effects.save(a,l);a.show();e.effects.createWrapper(a);var f=d=="up"||d=="down"?"top":"left";d=d=="up"||d=="left"?"pos":"neg";c=b.options.distance||(f=="top"?a.outerHeight({margin:true})/3:a.outerWidth({margin:true})/
+(function(e){e.effects.bounce=function(b){return this.queue(function(){var a=e(this),l=["position","top","bottom","left","right"],h=e.effects.setMode(a,b.options.mode||"effect"),d=b.options.direction||"up",c=b.options.distance||20,m=b.options.times||5,i=b.duration||250;/show|hide/.test(h)&&l.push("opacity");e.effects.save(a,l);a.show();e.effects.createWrapper(a);var f=d=="up"||d=="down"?"top":"left";d=d=="up"||d=="left"?"pos":"neg";c=b.options.distance||(f=="top"?a.outerHeight({margin:true})/3:a.outerWidth({margin:true})/
 3);if(h=="show")a.css("opacity",0).css(f,d=="pos"?-c:c);if(h=="hide")c/=m*2;h!="hide"&&m--;if(h=="show"){var g={opacity:1};g[f]=(d=="pos"?"+=":"-=")+c;a.animate(g,i/2,b.options.easing);c/=2;m--}for(g=0;g<m;g++){var j={},k={};j[f]=(d=="pos"?"-=":"+=")+c;k[f]=(d=="pos"?"+=":"-=")+c;a.animate(j,i/2,b.options.easing).animate(k,i/2,b.options.easing);c=h=="hide"?c*2:c/2}if(h=="hide"){g={opacity:0};g[f]=(d=="pos"?"-=":"+=")+c;a.animate(g,i/2,b.options.easing,function(){a.hide();e.effects.restore(a,l);e.effects.removeWrapper(a);
 b.callback&&b.callback.apply(this,arguments)})}else{j={};k={};j[f]=(d=="pos"?"-=":"+=")+c;k[f]=(d=="pos"?"+=":"-=")+c;a.animate(j,i/2,b.options.easing).animate(k,i/2,b.options.easing,function(){e.effects.restore(a,l);e.effects.removeWrapper(a);b.callback&&b.callback.apply(this,arguments)})}a.queue("fx",function(){a.dequeue()});a.dequeue()})}})(jQuery);

Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.clip.min.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.clip.min.js?rev=1090153&r1=1090152&r2=1090153&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.clip.min.js (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.clip.min.js Fri Apr  8 08:07:00 2011
@@ -1,7 +1,7 @@
 /*
- * jQuery UI Effects Clip 1.8.6
+ * jQuery UI Effects Clip 1.8.11
  *
- * Copyright 2010, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
  * http://jquery.org/license
  *
@@ -10,5 +10,5 @@
  * Depends:
  * jquery.effects.core.js
  */
-(function(b){b.effects.clip=function(e){return this.queue(function(){var a=b(this),i=["position","top","left","height","width"],f=b.effects.setMode(a,e.options.mode||"hide"),c=e.options.direction||"vertical";b.effects.save(a,i);a.show();var d=b.effects.createWrapper(a).css({overflow:"hidden"});d=a[0].tagName=="IMG"?d:a;var g={size:c=="vertical"?"height":"width",position:c=="vertical"?"top":"left"};c=c=="vertical"?d.height():d.width();if(f=="show"){d.css(g.size,0);d.css(g.position,c/2)}var h={};h[g.size]=
-f=="show"?c:0;h[g.position]=f=="show"?0:c/2;d.animate(h,{queue:false,duration:e.duration,easing:e.options.easing,complete:function(){f=="hide"&&a.hide();b.effects.restore(a,i);b.effects.removeWrapper(a);e.callback&&e.callback.apply(a[0],arguments);a.dequeue()}})})}})(jQuery);
+(function(b){b.effects.clip=function(e){return this.queue(function(){var a=b(this),i=["position","top","bottom","left","right","height","width"],f=b.effects.setMode(a,e.options.mode||"hide"),c=e.options.direction||"vertical";b.effects.save(a,i);a.show();var d=b.effects.createWrapper(a).css({overflow:"hidden"});d=a[0].tagName=="IMG"?d:a;var g={size:c=="vertical"?"height":"width",position:c=="vertical"?"top":"left"};c=c=="vertical"?d.height():d.width();if(f=="show"){d.css(g.size,0);d.css(g.position,
+c/2)}var h={};h[g.size]=f=="show"?c:0;h[g.position]=f=="show"?0:c/2;d.animate(h,{queue:false,duration:e.duration,easing:e.options.easing,complete:function(){f=="hide"&&a.hide();b.effects.restore(a,i);b.effects.removeWrapper(a);e.callback&&e.callback.apply(a[0],arguments);a.dequeue()}})})}})(jQuery);
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.core.js (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.core.js Fri Apr  8 08:07:00 2011
@@ -1,7 +1,7 @@
 /*
* jQuery UI Effects 1.8.6
  *
- * Copyright 2010, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
  * http://jquery.org/license
  *
@@ -231,8 +231,7 @@ $.effects.animateClass = function(value,
  easing = null;
  }
 
- return this.each(function() {
-
+ return this.queue('fx', function() {
  var that = $(this),
  originalStyleAttr = that.attr('style') || ' ',
  originalStyle = filterStyles(getElementStyles.call(this)),
@@ -260,6 +259,13 @@ $.effects.animateClass = function(value,
  }
  if (callback) { callback.apply(this, arguments); }
  });
+
+ // $.animate adds a function to the end of the queue
+ // but we want it at the front
+ var queue = $.queue(this),
+ anim = queue.splice(queue.length - 1, 1)[0];
+ queue.splice(1, 0, anim);
+ $.dequeue(this);
  });
 };
 
@@ -301,7 +307,7 @@ $.fn.extend({
 /******************************************************************************/
 
 $.extend($.effects, {
- version: "1.8.6",
+ version: "1.8.11",
 
  // Saves a set of properties in a data storage
  save: function(element, set) {
@@ -382,7 +388,7 @@ $.extend($.effects, {
  props[pos] = 'auto';
  }
  });
- element.css({position: 'relative', top: 0, left: 0 });
+ element.css({position: 'relative', top: 0, left: 0, right: 'auto', bottom: 'auto' });
  }
 
  return wrapper.css(props).show();
@@ -432,7 +438,7 @@ function _normalizeArguments(effect, opt
 
  speed = speed || options.duration;
  speed = $.fx.off ? 0 : typeof speed == 'number'
- ? speed : $.fx.speeds[speed] || $.fx.speeds._default;
+ ? speed : speed in $.fx.speeds ? $.fx.speeds[speed] : $.fx.speeds._default;
 
  callback = callback || options.complete;
 
@@ -1,7 +1,7 @@
 /*
- * jQuery UI Effects 1.8.6
+ * jQuery UI Effects 1.8.11
  *

Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.drop.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.drop.js?rev=1090153&r1=1090152&r2=1090153&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.accordion.js (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.accordion.js Fri Apr  8 08:07:00 2011
@@ -1,7 +1,7 @@
 /*
* jQuery UI Accordion 1.8.6
  *
- * Copyright 2010, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
  * http://jquery.org/license
  *
@@ -114,6 +114,7 @@ $.widget( "ui.accordion", {
  .not( self.active || "" )
  .attr({
  "aria-expanded": "false",
+ "aria-selected": "false",
  tabIndex: -1
  })
  .next()
@@ -126,6 +127,7 @@ $.widget( "ui.accordion", {
  self.active
  .attr({
  "aria-expanded": "true",
+ "aria-selected": "true",
  tabIndex: 0
  });
  }
@@ -173,6 +175,7 @@ $.widget( "ui.accordion", {
  .removeClass( "ui-accordion-header ui-accordion-disabled ui-helper-reset ui-state-default ui-corner-all ui-state-active ui-state-disabled ui-corner-top" )
  .removeAttr( "role" )
  .removeAttr( "aria-expanded" )
+ .removeAttr( "aria-selected" )
  .removeAttr( "tabIndex" );
 
  this.headers.find( "a" ).removeAttr( "tabIndex" );
@@ -347,8 +350,26 @@ $.widget( "ui.accordion", {
  return;
  }
 
+ // find elements to show and hide
+ var active = this.active,
+ toShow = clicked.next(),
+ toHide = this.active.next(),
+ data = {
+ options: options,
+ newHeader: clickedIsActive && options.collapsible ? $([]) : clicked,
+ oldHeader: this.active,
+ newContent: clickedIsActive && options.collapsible ? $([]) : toShow,
+ oldContent: toHide
+ },
+ down = this.headers.index( this.active[0] ) > this.headers.index( clicked[0] );
+
+ // when the call to ._toggle() comes after the class changes
+ // it causes a very odd bug in IE 8 (see #6720)
+ this.active = clickedIsActive ? $([]) : clicked;
+ this._toggle( toShow, toHide, data, clickedIsActive, down );
+
  // switch classes
- this.active
+ active
  .removeClass( "ui-state-active ui-corner-top" )
  .addClass( "ui-state-default ui-corner-all" )
  .children( ".ui-icon" )
@@ -366,21 +387,6 @@ $.widget( "ui.accordion", {
  .addClass( "ui-accordion-content-active" );
  }
 
- // find elements to show and hide
- var toShow = clicked.next(),
- toHide = this.active.next(),
- data = {
- options: options,
- newHeader: clickedIsActive && options.collapsible ? $([]) : clicked,
- oldHeader: this.active,
- newContent: clickedIsActive && options.collapsible ? $([]) : toShow,
- oldContent: toHide
- },
- down = this.headers.index( this.active[0] ) > this.headers.index( clicked[0] );
-
- this.active = clickedIsActive ? $([]) : clicked;
- this._toggle( toShow, toHide, data, clickedIsActive, down );
-
  return;
  },
 
@@ -474,12 +480,14 @@ $.widget( "ui.accordion", {
  toHide.prev()
  .attr({
  "aria-expanded": "false",
+ "aria-selected": "false",
  tabIndex: -1
  })
  .blur();
  toShow.prev()
  .attr({
  "aria-expanded": "true",
+ "aria-selected": "true",
  tabIndex: 0
  })
  .focus();
@@ -500,13 +508,17 @@ $.widget( "ui.accordion", {
 
  // other classes are removed before the animation; this one needs to stay until completed
  this.toHide.removeClass( "ui-accordion-content-active" );
+ // Work around for rendering bug in IE (#5421)
+ if ( this.toHide.length ) {
+ this.toHide.parent()[0].className = this.toHide.parent()[0].className;
+ }
 
  this._trigger( "change", null, this.data );
  }
 });
 
 $.extend( $.ui.accordion, {
- version: "1.8.6",
+ version: "1.8.11",
  animations: {
  slide: function( options, additions ) {
  options = $.extend({
@@ -1,7 +1,7 @@
 /*
- * jQuery UI Accordion 1.8.6
+ * jQuery UI Accordion 1.8.11
  *

Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.autocomplete.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.autocomplete.js?rev=1090153&r1=1090152&r2=1090153&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.datepicker.js (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.datepicker.js Fri Apr  8 08:07:00 2011
@@ -1,7 +1,7 @@
 /*
* jQuery UI Datepicker 1.8.6
  *
- * Copyright 2010, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
  * http://jquery.org/license
  *
@@ -12,7 +12,7 @@
  */
 (function( $, undefined ) {
 
-$.extend($.ui, { datepicker: { version: "1.8.6" } });
+$.extend($.ui, { datepicker: { version: "1.8.11" } });
 
 var PROP_NAME = 'datepicker';
 var dpuuid = new Date().getTime();
@@ -107,7 +107,7 @@ function Datepicker() {
  autoSize: false // True to size the input for the date format, false to leave as is
  };
  $.extend(this._defaults, this.regional['']);
- this.dpDiv = $('<div id="' + this._mainDivId + '" class="ui-datepicker ui-widget ui-widget-content ui-helper-clearfix ui-corner-all ui-helper-hidden-accessible"></div>');
+ this.dpDiv = $('<div id="' + this._mainDivId + '" class="ui-datepicker ui-widget ui-widget-content ui-helper-clearfix ui-corner-all"></div>');
 }
 
 $.extend(Datepicker.prototype, {
@@ -272,6 +272,7 @@ $.extend(Datepicker.prototype, {
  this._setDate(inst, this._getDefaultDate(inst), true);
  this._updateDatepicker(inst);
  this._updateAlternate(inst);
+ inst.dpDiv.show();
  },
 
  /* Pop-up the date picker in a "dialog" box.
@@ -443,7 +444,14 @@ $.extend(Datepicker.prototype, {
  this._hideDatepicker();
  }
  var date = this._getDateDatepicker(target, true);
+ var minDate = this._getMinMaxDate(inst, 'min');
+ var maxDate = this._getMinMaxDate(inst, 'max');
  extendRemove(inst.settings, settings);
+ // reformat the old minDate/maxDate values if dateFormat changes and a new minDate/maxDate isn't provided
+ if (minDate !== null && settings['dateFormat'] !== undefined && settings['minDate'] === undefined)
+ inst.settings.minDate = this._formatDate(inst, minDate);
+ if (maxDate !== null && settings['dateFormat'] !== undefined && settings['maxDate'] === undefined)
+ inst.settings.maxDate = this._formatDate(inst, maxDate);
  this._attachments($(target), inst);
  this._autoSize(inst);
  this._setDateDatepicker(target, date);
@@ -499,8 +507,8 @@ $.extend(Datepicker.prototype, {
  case 9: $.datepicker._hideDatepicker();
  handled = false;
  break; // hide on tab out
- case 13: var sel = $('td.' + $.datepicker._dayOverClass, inst.dpDiv).
- add($('td.' + $.datepicker._currentClass, inst.dpDiv));
+ case 13: var sel = $('td.' + $.datepicker._dayOverClass + ':not(.' +
+ $.datepicker._currentClass + ')', inst.dpDiv);
  if (sel[0])
  $.datepicker._selectDay(event.target, inst.selectedMonth, inst.selectedYear, sel[0]);
  else
@@ -564,7 +572,7 @@ $.extend(Datepicker.prototype, {
  if ($.datepicker._get(inst, 'constrainInput')) {
  var chars = $.datepicker._possibleChars($.datepicker._get(inst, 'dateFormat'));
  var chr = String.fromCharCode(event.charCode == undefined ? event.keyCode : event.charCode);
- return event.ctrlKey || (chr < ' ' || !chars || chars.indexOf(chr) > -1);
+ return event.ctrlKey || event.metaKey || (chr < ' ' || !chars || chars.indexOf(chr) > -1);
  }
  },
 
@@ -624,6 +632,8 @@ $.extend(Datepicker.prototype, {
  }
  var offset = {left: $.datepicker._pos[0], top: $.datepicker._pos[1]};
  $.datepicker._pos = null;
+ //to avoid flashes on Firefox
+ inst.dpDiv.empty();
  // determine sizing offscreen
  inst.dpDiv.css({position: 'absolute', display: 'block', top: '-1000px'});
  $.datepicker._updateDatepicker(inst);
@@ -638,10 +648,12 @@ $.extend(Datepicker.prototype, {
  var duration = $.datepicker._get(inst, 'duration');
  var postProcess = function() {
  $.datepicker._datepickerShowing = true;
- var borders = $.datepicker._getBorders(inst.dpDiv);
- inst.dpDiv.find('iframe.ui-datepicker-cover'). // IE6- only
- css({left: -borders[0], top: -borders[1],
+ var cover = inst.dpDiv.find('iframe.ui-datepicker-cover'); // IE6- only
+ if( !! cover.length ){
+ var borders = $.datepicker._getBorders(inst.dpDiv);
+ cover.css({left: -borders[0], top: -borders[1],
  width: inst.dpDiv.outerWidth(), height: inst.dpDiv.outerHeight()});
+ }
  };
  inst.dpDiv.zIndex($(input).zIndex()+1);
  if ($.effects && $.effects[showAnim])
@@ -660,12 +672,12 @@ $.extend(Datepicker.prototype, {
  _updateDatepicker: function(inst) {
  var self = this;
  var borders = $.datepicker._getBorders(inst.dpDiv);
- inst.dpDiv.empty().append(this._generateHTML(inst))
- .find('iframe.ui-datepicker-cover') // IE6- only
- .css({left: -borders[0], top: -borders[1],
- width: inst.dpDiv.outerWidth(), height: inst.dpDiv.outerHeight()})
- .end()
- .find('button, .ui-datepicker-prev, .ui-datepicker-next, .ui-datepicker-calendar td a')
+ inst.dpDiv.empty().append(this._generateHTML(inst));
+ var cover = inst.dpDiv.find('iframe.ui-datepicker-cover'); // IE6- only
+ if( !!cover.length ){ //avoid call to outerXXXX() when not in IE6
+ cover.css({left: -borders[0], top: -borders[1], width: inst.dpDiv.outerWidth(), height: inst.dpDiv.outerHeight()})
+ }
+ inst.dpDiv.find('button, .ui-datepicker-prev, .ui-datepicker-next, .ui-datepicker-calendar td a')
  .bind('mouseout', function(){
  $(this).removeClass('ui-state-hover');
  if(this.className.indexOf('ui-datepicker-prev') != -1) $(this).removeClass('ui-datepicker-prev-hover');
@@ -695,8 +707,21 @@ $.extend(Datepicker.prototype, {
  inst.dpDiv[(this._get(inst, 'isRTL') ? 'add' : 'remove') +
  'Class']('ui-datepicker-rtl');
  if (inst == $.datepicker._curInst && $.datepicker._datepickerShowing && inst.input &&
- inst.input.is(':visible') && !inst.input.is(':disabled'))
+ // #6694 - don't focus the input if it's already focused
+ // this breaks the change event in IE
+ inst.input.is(':visible') && !inst.input.is(':disabled') && inst.input[0] != document.activeElement)
  inst.input.focus();
+ // deffered render of the years select (to avoid flashes on Firefox)
+ if( inst.yearshtml ){
+ var origyearshtml = inst.yearshtml;
+ setTimeout(function(){
+ //assure that inst.yearshtml didn't change.
+ if( origyearshtml === inst.yearshtml ){
+ inst.dpDiv.find('select.ui-datepicker-year:first').replaceWith(inst.yearshtml);
+ }
+ origyearshtml = inst.yearshtml = null;
+ }, 0);
+ }
  },
 
  /* Retrieve the size of left and top borders for an element.
@@ -736,7 +761,7 @@ $.extend(Datepicker.prototype, {
  _findPos: function(obj) {
  var inst = this._getInst(obj);
  var isRTL = this._get(inst, 'isRTL');
-        while (obj && (obj.type == 'hidden' || obj.nodeType != 1)) {
+        while (obj && (obj.type == 'hidden' || obj.nodeType != 1 || $.expr.filters.hidden(obj))) {
             obj = obj[isRTL ? 'previousSibling' : 'nextSibling'];
         }
         var position = $(obj).offset();
@@ -950,6 +975,8 @@ $.extend(Datepicker.prototype, {
  if (value == '')
  return null;
  var shortYearCutoff = (settings ? settings.shortYearCutoff : null) || this._defaults.shortYearCutoff;
+ shortYearCutoff = (typeof shortYearCutoff != 'string' ? shortYearCutoff :
+ new Date().getFullYear() % 100 + parseInt(shortYearCutoff, 10));
  var dayNamesShort = (settings ? settings.dayNamesShort : null) || this._defaults.dayNamesShort;
  var dayNames = (settings ? settings.dayNames : null) || this._defaults.dayNames;
  var monthNamesShort = (settings ? settings.monthNamesShort : null) || this._defaults.monthNamesShort;
@@ -968,9 +995,9 @@ $.extend(Datepicker.prototype, {
  };
  // Extract a number from the string value
  var getNumber = function(match) {
- lookAhead(match);
+ var isDoubled = lookAhead(match);
  var size = (match == '@' ? 14 : (match == '!' ? 20 :
- (match == 'y' ? 4 : (match == 'o' ? 3 : 2))));
+ (match == 'y' && isDoubled ? 4 : (match == 'o' ? 3 : 2))));
  var digits = new RegExp('^\\d{1,' + size + '}');
  var num = value.substring(iValue).match(digits);
  if (!num)
@@ -1300,16 +1327,16 @@ $.extend(Datepicker.prototype, {
  }
  return new Date(year, month, day);
  };
- date = (date == null ? defaultDate : (typeof date == 'string' ? offsetString(date) :
- (typeof date == 'number' ? (isNaN(date) ? defaultDate : offsetNumeric(date)) : date)));
- date = (date && date.toString() == 'Invalid Date' ? defaultDate : date);
- if (date) {
- date.setHours(0);
- date.setMinutes(0);
- date.setSeconds(0);
- date.setMilliseconds(0);
+ var newDate = (date == null || date === '' ? defaultDate : (typeof date == 'string' ? offsetString(date) :
+ (typeof date == 'number' ? (isNaN(date) ? defaultDate : offsetNumeric(date)) : new Date(date.getTime()))));
+ newDate = (newDate && newDate.toString() == 'Invalid Date' ? defaultDate : newDate);
+ if (newDate) {
+ newDate.setHours(0);
+ newDate.setMinutes(0);
+ newDate.setSeconds(0);
+ newDate.setMilliseconds(0);
  }
- return this._daylightSavingAdjust(date);
+ return this._daylightSavingAdjust(newDate);
  },
 
  /* Handle switch to/from daylight saving.
@@ -1326,13 +1353,13 @@ $.extend(Datepicker.prototype, {
 
  /* Set the date(s) directly. */
  _setDate: function(inst, date, noChange) {
- var clear = !(date);
+ var clear = !date;
  var origMonth = inst.selectedMonth;
  var origYear = inst.selectedYear;
- date = this._restrictMinMax(inst, this._determineDate(inst, date, new Date()));
- inst.selectedDay = inst.currentDay = date.getDate();
- inst.drawMonth = inst.selectedMonth = inst.currentMonth = date.getMonth();
- inst.drawYear = inst.selectedYear = inst.currentYear = date.getFullYear();
+ var newDate = this._restrictMinMax(inst, this._determineDate(inst, date, new Date()));
+ inst.selectedDay = inst.currentDay = newDate.getDate();
+ inst.drawMonth = inst.selectedMonth = inst.currentMonth = newDate.getMonth();
+ inst.drawYear = inst.selectedYear = inst.currentYear = newDate.getFullYear();
  if ((origMonth != inst.selectedMonth || origYear != inst.selectedYear) && !noChange)
  this._notifyChange(inst);
  this._adjustInstDate(inst);
@@ -1548,6 +1575,7 @@ $.extend(Datepicker.prototype, {
  if (!showMonthAfterYear)
  html += monthHtml + (secondary || !(changeMonth && changeYear) ? '&#xa0;' : '');
  // year selection
+ inst.yearshtml = '';
  if (secondary || !changeYear)
  html += '<span class="ui-datepicker-year">' + drawYear + '</span>';
  else {
@@ -1564,16 +1592,24 @@ $.extend(Datepicker.prototype, {
  var endYear = Math.max(year, determineYear(years[1] || ''));
  year = (minDate ? Math.max(year, minDate.getFullYear()) : year);
  endYear = (maxDate ? Math.min(endYear, maxDate.getFullYear()) : endYear);
- html += '<select class="ui-datepicker-year" ' +
+ inst.yearshtml += '<select class="ui-datepicker-year" ' +
  'onchange="DP_jQuery_' + dpuuid + '.datepicker._selectMonthYear(\'#' + inst.id + '\', this, \'Y\');" ' +
  'onclick="DP_jQuery_' + dpuuid + '.datepicker._clickMonthYear(\'#' + inst.id + '\');"' +
  '>';
  for (; year <= endYear; year++) {
- html += '<option value="' + year + '"' +
+ inst.yearshtml += '<option value="' + year + '"' +
  (year == drawYear ? ' selected="selected"' : '') +
  '>' + year + '</option>';
  }
- html += '</select>';
+ inst.yearshtml += '</select>';
+ //when showing there is no need for later update
+ if( ! $.browser.mozilla ){
+ html += inst.yearshtml;
+ inst.yearshtml = null;
+ } else {
+ // will be replaced later with inst.yearshtml
+ html += '<select class="ui-datepicker-year"><option value="' + drawYear + '" selected="selected">' + drawYear + '</option></select>';
+ }
  }
  html += this._get(inst, 'yearSuffix');
  if (showMonthAfterYear)
@@ -1601,9 +1637,9 @@ $.extend(Datepicker.prototype, {
  _restrictMinMax: function(inst, date) {
  var minDate = this._getMinMaxDate(inst, 'min');
  var maxDate = this._getMinMaxDate(inst, 'max');
- date = (minDate && date < minDate ? minDate : date);
- date = (maxDate && date > maxDate ? maxDate : date);
- return date;
+ var newDate = (minDate && date < minDate ? minDate : date);
+ newDate = (maxDate && newDate > maxDate ? maxDate : newDate);
+ return newDate;
  },
 
  /* Notify change of month/year. */
@@ -1627,7 +1663,7 @@ $.extend(Datepicker.prototype, {
 
  /* Find the number of days in a given month. */
  _getDaysInMonth: function(year, month) {
- return 32 - new Date(year, month, 32).getDate();
+ return 32 - this._daylightSavingAdjust(new Date(year, month, 32)).getDate();
  },
 
  /* Find the day of the week of the first of a month. */
@@ -1697,7 +1733,12 @@ function isArray(a) {
                     Object - settings for attaching new datepicker functionality
    @return  jQuery object */
 $.fn.datepicker = function(options){
-
+
+ /* Verify an empty collection wasn't passed - Fixes #6976 */
+ if ( !this.length ) {
+ return this;
+ }
+
  /* Initialise the date picker. */
  if (!$.datepicker.initialized) {
  $(document).mousedown($.datepicker._checkExternalClick).
@@ -1723,7 +1764,7 @@ $.fn.datepicker = function(options){
 $.datepicker = new Datepicker(); // singleton instance
 $.datepicker.initialized = false;
 $.datepicker.uuid = new Date().getTime();
-$.datepicker.version = "1.8.6";
+$.datepicker.version = "1.8.11";
 
 // Workaround for #4055
 // Add another global to avoid noConflict issues with inline event handlers
@@ -1,7 +1,7 @@
 /*
- * jQuery UI Datepicker 1.8.6
+ * jQuery UI Datepicker 1.8.11
  *

Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.dialog.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.dialog.js?rev=1090153&r1=1090152&r2=1090153&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.dialog.js (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.dialog.js Fri Apr  8 08:07:00 2011
@@ -1,7 +1,7 @@
 /*
* jQuery UI Dialog 1.8.6
  *
- * Copyright 2010, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
  * http://jquery.org/license
  *
@@ -57,7 +57,6 @@ $.widget("ui.dialog", {
  position: {
  my: 'center',
  at: 'center',
- of: window,
  collision: 'fit',
  // ensure that the titlebar is never outside the document
  using: function(pos) {
@@ -228,7 +227,7 @@ $.widget("ui.dialog", {
 
  close: function(event) {
  var self = this,
- maxZ;
+ maxZ, thisZ;
 
  if (false === self._trigger('beforeClose', event)) {
  return;
@@ -257,7 +256,10 @@ $.widget("ui.dialog", {
  maxZ = 0;
  $('.ui-dialog').each(function() {
  if (this !== self.uiDialog[0]) {
- maxZ = Math.max(maxZ, $(this).css('z-index'));
+ thisZ = $(this).css('z-index');
+ if(!isNaN(thisZ)) {
+ maxZ = Math.max(maxZ, thisZ);
+ }
  }
  });
  $.ui.dialog.maxZ = maxZ;
@@ -525,7 +527,7 @@ $.widget("ui.dialog", {
  this.uiDialog
  // workaround for jQuery bug #5781 http://dev.jquery.com/ticket/5781
  .css({ top: 0, left: 0 })
- .position(position);
+ .position($.extend({ of: window }, position));
  if (!isVisible) {
  this.uiDialog.hide();
  }
@@ -586,7 +588,7 @@ $.widget("ui.dialog", {
  }
  break;
  case "draggable":
- var isDraggable = uiDialog.is( ":data(draggable)" )
+ var isDraggable = uiDialog.is( ":data(draggable)" );
  if ( isDraggable && !value ) {
  uiDialog.draggable( "destroy" );
  }
@@ -600,7 +602,7 @@ $.widget("ui.dialog", {
  break;
  case "resizable":
  // currently resizable, becoming non-resizable
- var isResizable = uiDialog.is( ":data(resizable)" )
+ var isResizable = uiDialog.is( ":data(resizable)" );
  if (isResizable && !value) {
  uiDialog.resizable('destroy');
  }
@@ -630,7 +632,8 @@ $.widget("ui.dialog", {
  */
  var options = this.options,
  nonContentHeight,
- minContentHeight;
+ minContentHeight,
+ isVisible = this.uiDialog.is( ":visible" );
 
  // reset content sizing
  this.element.show().css({
@@ -662,7 +665,9 @@ $.widget("ui.dialog", {
  } else {
  this.uiDialog.show();
  var autoHeight = this.element.css( "height", "auto" ).height();
- this.uiDialog.hide();
+ if ( !isVisible ) {
+ this.uiDialog.hide();
+ }
  this.element.height( Math.max( autoHeight, minContentHeight ) );
  }
  } else {
@@ -676,7 +681,7 @@ $.widget("ui.dialog", {
 });
 
 $.extend($.ui.dialog, {
- version: "1.8.6",
+ version: "1.8.11",
 
  uuid: 0,
  maxZ: 0,
@@ -750,7 +755,10 @@ $.extend($.ui.dialog.overlay, {
  },
 
  destroy: function($el) {
- this.oldInstances.push(this.instances.splice($.inArray($el, this.instances), 1)[0]);
+ var indexOf = $.inArray($el, this.instances);
+ if (indexOf != -1){
+ this.oldInstances.push(this.instances.splice(indexOf, 1)[0]);
+ }
 
  if (this.instances.length === 0) {
  $([document, window]).unbind('.dialog-overlay');
@@ -1,7 +1,7 @@
 /*
- * jQuery UI Dialog 1.8.6
+ * jQuery UI Dialog 1.8.11
  *

Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.draggable.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.draggable.js?rev=1090153&r1=1090152&r2=1090153&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.draggable.js (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.draggable.js Fri Apr  8 08:07:00 2011
@@ -1,7 +1,7 @@
 /*
* jQuery UI Draggable 1.8.6
  *
- * Copyright 2010, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
  * http://jquery.org/license
  *
@@ -192,8 +192,8 @@ $.widget("ui.draggable", $.ui.mouse, {
  this.dropped = false;
  }
 
- //if the original element is removed, don't bother to continue
- if(!this.element[0] || !this.element[0].parentNode)
+ //if the original element is removed, don't bother to continue if helper is set to "original"
+ if((!this.element[0] || !this.element[0].parentNode) && this.options.helper == "original")
  return false;
 
  if((this.options.revert == "invalid" && !dropped) || (this.options.revert == "valid" && dropped) || this.options.revert === true || ($.isFunction(this.options.revert) && this.options.revert.call(this.element, dropped))) {
@@ -317,7 +317,9 @@ $.widget("ui.draggable", $.ui.mouse, {
  _cacheMargins: function() {
  this.margins = {
  left: (parseInt(this.element.css("marginLeft"),10) || 0),
- top: (parseInt(this.element.css("marginTop"),10) || 0)
+ top: (parseInt(this.element.css("marginTop"),10) || 0),
+ right: (parseInt(this.element.css("marginRight"),10) || 0),
+ bottom: (parseInt(this.element.css("marginBottom"),10) || 0)
  };
  },
 
@@ -333,10 +335,10 @@ $.widget("ui.draggable", $.ui.mouse, {
  var o = this.options;
  if(o.containment == 'parent') o.containment = this.helper[0].parentNode;
  if(o.containment == 'document' || o.containment == 'window') this.containment = [
- 0 - this.offset.relative.left - this.offset.parent.left,
- 0 - this.offset.relative.top - this.offset.parent.top,
- $(o.containment == 'document' ? document : window).width() - this.helperProportions.width - this.margins.left,
- ($(o.containment == 'document' ? document : window).height() || document.body.parentNode.scrollHeight) - this.helperProportions.height - this.margins.top
+ (o.containment == 'document' ? 0 : $(window).scrollLeft()) - this.offset.relative.left - this.offset.parent.left,
+ (o.containment == 'document' ? 0 : $(window).scrollTop()) - this.offset.relative.top - this.offset.parent.top,
+ (o.containment == 'document' ? 0 : $(window).scrollLeft()) + $(o.containment == 'document' ? document : window).width() - this.helperProportions.width - this.margins.left,
+ (o.containment == 'document' ? 0 : $(window).scrollTop()) + ($(o.containment == 'document' ? document : window).height() || document.body.parentNode.scrollHeight) - this.helperProportions.height - this.margins.top
  ];
 
  if(!(/^(document|window|parent)$/).test(o.containment) && o.containment.constructor != Array) {
@@ -345,10 +347,10 @@ $.widget("ui.draggable", $.ui.mouse, {
  var over = ($(ce).css("overflow") != 'hidden');
 
  this.containment = [
- co.left + (parseInt($(ce).css("borderLeftWidth"),10) || 0) + (parseInt($(ce).css("paddingLeft"),10) || 0) - this.margins.left,
- co.top + (parseInt($(ce).css("borderTopWidth"),10) || 0) + (parseInt($(ce).css("paddingTop"),10) || 0) - this.margins.top,
- co.left+(over ? Math.max(ce.scrollWidth,ce.offsetWidth) : ce.offsetWidth) - (parseInt($(ce).css("borderLeftWidth"),10) || 0) - (parseInt($(ce).css("paddingRight"),10) || 0) - this.helperProportions.width - this.margins.left,
- co.top+(over ? Math.max(ce.scrollHeight,ce.offsetHeight) : ce.offsetHeight) - (parseInt($(ce).css("borderTopWidth"),10) || 0) - (parseInt($(ce).css("paddingBottom"),10) || 0) - this.helperProportions.height - this.margins.top
+ co.left + (parseInt($(ce).css("borderLeftWidth"),10) || 0) + (parseInt($(ce).css("paddingLeft"),10) || 0),
+ co.top + (parseInt($(ce).css("borderTopWidth"),10) || 0) + (parseInt($(ce).css("paddingTop"),10) || 0),
+ co.left+(over ? Math.max(ce.scrollWidth,ce.offsetWidth) : ce.offsetWidth) - (parseInt($(ce).css("borderLeftWidth"),10) || 0) - (parseInt($(ce).css("paddingRight"),10) || 0) - this.helperProportions.width - this.margins.left - this.margins.right,
+ co.top+(over ? Math.max(ce.scrollHeight,ce.offsetHeight) : ce.offsetHeight) - (parseInt($(ce).css("borderTopWidth"),10) || 0) - (parseInt($(ce).css("paddingBottom"),10) || 0) - this.helperProportions.height - this.margins.top  - this.margins.bottom
  ];
  } else if(o.containment.constructor == Array) {
  this.containment = o.containment;
@@ -459,7 +461,7 @@ $.widget("ui.draggable", $.ui.mouse, {
 });
 
 $.extend($.ui.draggable, {
- version: "1.8.6"
+ version: "1.8.11"
 });
 
 $.ui.plugin.add("draggable", "connectToSortable", {
@@ -475,7 +477,7 @@ $.ui.plugin.add("draggable", "connectToS
  instance: sortable,
  shouldRevert: sortable.options.revert
  });
- sortable._refreshItems(); //Do a one-time refresh at start to refresh the containerCache
+ sortable.refreshPositions(); // Call the sortable's refreshPositions at drag start to refresh the containerCache since the sortable container cache is used in drag and needs to be up to date (this will ensure it's initialised as well as being kept in step with any changes that might have happened on the page).
  sortable._trigger("activate", event, uiSortable);
  }
  });
@@ -1,7 +1,7 @@
 /*
- * jQuery UI Draggable 1.8.6
+ * jQuery UI Draggable 1.8.11
  *

Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.droppable.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.droppable.js?rev=1090153&r1=1090152&r2=1090153&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.droppable.js (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.droppable.js Fri Apr  8 08:07:00 2011
@@ -1,7 +1,7 @@
 /*
* jQuery UI Droppable 1.8.6
  *
- * Copyright 2010, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
  * http://jquery.org/license
  *
@@ -147,7 +147,7 @@ $.widget("ui.droppable", {
 });
 
 $.extend($.ui.droppable, {
- version: "1.8.6"
+ version: "1.8.11"
 });
 
 $.ui.intersect = function(draggable, droppable, toleranceMode) {
@@ -212,11 +212,11 @@ $.ui.ddmanager = {
  for (var j=0; j < list.length; j++) { if(list[j] == m[i].element[0]) { m[i].proportions.height = 0; continue droppablesLoop; } }; //Filter out elements in the current dragged item
  m[i].visible = m[i].element.css("display") != "none"; if(!m[i].visible) continue; //If the element is not visible, continue
 
+ if(type == "mousedown") m[i]._activate.call(m[i], event); //Activate the droppable if used directly from draggables
+
  m[i].offset = m[i].element.offset();
  m[i].proportions = { width: m[i].element[0].offsetWidth, height: m[i].element[0].offsetHeight };
 
- if(type == "mousedown") m[i]._activate.call(m[i], event); //Activate the droppable if used directly from draggables
-
  }
 
  },
@@ -1,7 +1,7 @@
 /*
- * jQuery UI Droppable 1.8.6
+ * jQuery UI Droppable 1.8.11
  *

Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.mouse.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.mouse.js?rev=1090153&r1=1090152&r2=1090153&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.progressbar.js (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.progressbar.js Fri Apr  8 08:07:00 2011
@@ -1,7 +1,7 @@
 /*
* jQuery UI Progressbar 1.8.6
  *
- * Copyright 2010, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
  * http://jquery.org/license
  *
@@ -15,11 +15,11 @@
 
 $.widget( "ui.progressbar", {
  options: {
- value: 0
+ value: 0,
+ max: 100
  },
 
  min: 0,
- max: 100,
 
  _create: function() {
  this.element
@@ -27,13 +27,14 @@ $.widget( "ui.progressbar", {
  .attr({
  role: "progressbar",
  "aria-valuemin": this.min,
- "aria-valuemax": this.max,
+ "aria-valuemax": this.options.max,
  "aria-valuenow": this._value()
  });
 
  this.valueDiv = $( "<div class='ui-progressbar-value ui-widget-header ui-corner-left'></div>" )
  .appendTo( this.element );
 
+ this.oldValue = this._value();
  this._refreshValue();
  },
 
@@ -63,8 +64,7 @@ $.widget( "ui.progressbar", {
  if ( key === "value" ) {
  this.options.value = value;
  this._refreshValue();
- this._trigger( "change" );
- if ( this._value() === this.max ) {
+ if ( this._value() === this.options.max ) {
  this._trigger( "complete" );
  }
  }
@@ -78,20 +78,31 @@ $.widget( "ui.progressbar", {
  if ( typeof val !== "number" ) {
  val = 0;
  }
- return Math.min( this.max, Math.max( this.min, val ) );
+ return Math.min( this.options.max, Math.max( this.min, val ) );
+ },
+
+ _percentage: function() {
+ return 100 * this._value() / this.options.max;
  },
 
  _refreshValue: function() {
  var value = this.value();
+ var percentage = this._percentage();
+
+ if ( this.oldValue !== value ) {
+ this.oldValue = value;
+ this._trigger( "change" );
+ }
+
  this.valueDiv
- .toggleClass( "ui-corner-right", value === this.max )
- .width( value + "%" );
+ .toggleClass( "ui-corner-right", value === this.options.max )
+ .width( percentage.toFixed(0) + "%" );
  this.element.attr( "aria-valuenow", value );
  }
 });
 
 $.extend( $.ui.progressbar, {
- version: "1.8.6"
+ version: "1.8.11"
 });
 
 })( jQuery );
@@ -1,7 +1,7 @@
 /*
- * jQuery UI Progressbar 1.8.6
+ * jQuery UI Progressbar 1.8.11
  *

Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.resizable.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.resizable.js?rev=1090153&r1=1090152&r2=1090153&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.resizable.js (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.resizable.js Fri Apr  8 08:07:00 2011
@@ -1,7 +1,7 @@
 /*
* jQuery UI Resizable 1.8.6
  *
- * Copyright 2010, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
  * http://jquery.org/license
  *
@@ -322,10 +322,10 @@ $.widget("ui.resizable", $.ui.mouse, {
 
  if(this._helper) {
  var pr = this._proportionallyResizeElements, ista = pr.length && (/textarea/i).test(pr[0].nodeName),
- soffseth = ista && $.ui.hasScroll(pr[0], 'left') /* TODO - jump height */ ? 0 : self.sizeDiff.height,
- soffsetw = ista ? 0 : self.sizeDiff.width;
+ soffseth = ista && $.ui.hasScroll(pr[0], 'left') /* TODO - jump height */ ? 0 : self.sizeDiff.height,
+ soffsetw = ista ? 0 : self.sizeDiff.width;
 
- var s = { width: (self.size.width - soffsetw), height: (self.size.height - soffseth) },
+ var s = { width: (self.helper.width()  - soffsetw), height: (self.helper.height() - soffseth) },
  left = (parseInt(self.element.css('left'), 10) + (self.position.left - self.originalPosition.left)) || null,
  top = (parseInt(self.element.css('top'), 10) + (self.position.top - self.originalPosition.top)) || null;
 
@@ -519,7 +519,7 @@ $.widget("ui.resizable", $.ui.mouse, {
 });
 
 $.extend($.ui.resizable, {
- version: "1.8.6"
+ version: "1.8.11"
 });
 
 /*
@@ -1,7 +1,7 @@
 /*
- * jQuery UI Resizable 1.8.6
+ * jQuery UI Resizable 1.8.11
  *

Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.selectable.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.selectable.js?rev=1090153&r1=1090152&r2=1090153&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.selectable.js (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.selectable.js Fri Apr  8 08:07:00 2011
@@ -1,7 +1,7 @@
 /*
* jQuery UI Selectable 1.8.6
  *
- * Copyright 2010, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
  * http://jquery.org/license
  *
@@ -260,7 +260,7 @@ $.widget("ui.selectable", $.ui.mouse, {
 });
 
 $.extend($.ui.selectable, {
- version: "1.8.6"
+ version: "1.8.11"
 });
 
 })(jQuery);
@@ -1,7 +1,7 @@
 /*
- * jQuery UI Selectable 1.8.6
+ * jQuery UI Selectable 1.8.11
  *

Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.slider.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.slider.js?rev=1090153&r1=1090152&r2=1090153&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.slider.js (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.slider.js Fri Apr  8 08:07:00 2011
@@ -1,7 +1,7 @@
 /*
* jQuery UI Slider 1.8.6
  *
- * Copyright 2010, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
  * http://jquery.org/license
  *
@@ -309,7 +309,9 @@ $.widget( "ui.slider", $.ui.mouse, {
  ( parseInt( closestHandle.css("marginTop"), 10 ) || 0)
  };
 
- this._slide( event, index, normValue );
+ if ( !this.handles.hasClass( "ui-state-hover" ) ) {
+ this._slide( event, index, normValue );
+ }
  this._animateOff = true;
  return true;
  },
@@ -583,14 +585,14 @@ $.widget( "ui.slider", $.ui.mouse, {
 
  // returns the step-aligned value that val is closest to, between (inclusive) min and max
  _trimAlignValue: function( val ) {
- if ( val < this._valueMin() ) {
+ if ( val <= this._valueMin() ) {
  return this._valueMin();
  }
- if ( val > this._valueMax() ) {
+ if ( val >= this._valueMax() ) {
  return this._valueMax();
  }
  var step = ( this.options.step > 0 ) ? this.options.step : 1,
- valModStep = val % step,
+ valModStep = (val - this._valueMin()) % step;
  alignValue = val - valModStep;
 
  if ( Math.abs(valModStep) * 2 >= step ) {
@@ -674,7 +676,7 @@ $.widget( "ui.slider", $.ui.mouse, {
 });
 
 $.extend( $.ui.slider, {
- version: "1.8.6"
+ version: "1.8.11"
 });
 
 }(jQuery));
@@ -1,7 +1,7 @@
 /*
- * jQuery UI Slider 1.8.6
+ * jQuery UI Slider 1.8.11
  *

Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.sortable.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.sortable.js?rev=1090153&r1=1090152&r2=1090153&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.sortable.js (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.sortable.js Fri Apr  8 08:07:00 2011
@@ -1,7 +1,7 @@
 /*
* jQuery UI Sortable 1.8.6
  *
- * Copyright 2010, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
  * http://jquery.org/license
  *
@@ -49,8 +49,8 @@ $.widget("ui.sortable", $.ui.mouse, {
  //Get the items
  this.refresh();
 
- //Let's determine if the items are floating
- this.floating = this.items.length ? (/left|right/).test(this.items[0].item.css('float')) : false;
+ //Let's determine if the items are being displayed horizontally
+ this.floating = this.items.length ? (/left|right/).test(this.items[0].item.css('float')) || (/inline|table-cell/).test(this.items[0].item.css('display')) : false;
 
  //Let's determine the parent's offset
  this.offset = this.element.offset();
@@ -360,7 +360,7 @@ $.widget("ui.sortable", $.ui.mouse, {
 
  if(this.dragging) {
 
- this._mouseUp();
+ this._mouseUp({ target: null });
 
  if(this.options.helper == "original")
  this.currentItem.css(this._storedCSS).removeClass("ui-sortable-helper");
@@ -378,21 +378,23 @@ $.widget("ui.sortable", $.ui.mouse, {
 
  }
 
- //$(this.placeholder[0]).remove(); would have been the jQuery way - unfortunately, it unbinds ALL events from the original node!
- if(this.placeholder[0].parentNode) this.placeholder[0].parentNode.removeChild(this.placeholder[0]);
- if(this.options.helper != "original" && this.helper && this.helper[0].parentNode) this.helper.remove();
-
- $.extend(this, {
- helper: null,
- dragging: false,
- reverting: false,
- _noFinalSort: null
- });
+ if (this.placeholder) {
+ //$(this.placeholder[0]).remove(); would have been the jQuery way - unfortunately, it unbinds ALL events from the original node!
+ if(this.placeholder[0].parentNode) this.placeholder[0].parentNode.removeChild(this.placeholder[0]);
+ if(this.options.helper != "original" && this.helper && this.helper[0].parentNode) this.helper.remove();
+
+ $.extend(this, {
+ helper: null,
+ dragging: false,
+ reverting: false,
+ _noFinalSort: null
+ });
 
- if(this.domPosition.prev) {
- $(this.domPosition.prev).after(this.currentItem);
- } else {
- $(this.domPosition.parent).prepend(this.currentItem);
+ if(this.domPosition.prev) {
+ $(this.domPosition.prev).after(this.currentItem);
+ } else {
+ $(this.domPosition.parent).prepend(this.currentItem);
+ }
  }
 
  return this;
@@ -1065,7 +1067,7 @@ $.widget("ui.sortable", $.ui.mouse, {
 });
 
 $.extend($.ui.sortable, {
- version: "1.8.6"
+ version: "1.8.11"
 });
 
 })(jQuery);
@@ -1,7 +1,7 @@
 /*
- * jQuery UI Sortable 1.8.6
+ * jQuery UI Sortable 1.8.11
  *

Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.tabs.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.tabs.js?rev=1090153&r1=1090152&r2=1090153&view=diff
==============================================================================
--- ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.tabs.js (original)
+++ ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.tabs.js Fri Apr  8 08:07:00 2011
@@ -1,7 +1,7 @@
 /*
* jQuery UI Tabs 1.8.6
  *
- * Copyright 2010, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
  * http://jquery.org/license
  *
@@ -126,7 +126,7 @@ $.widget( "ui.tabs", {
 
  // inline tab
  if ( fragmentId.test( href ) ) {
- self.panels = self.panels.add( self._sanitizeSelector( href ) );
+ self.panels = self.panels.add( self.element.find( self._sanitizeSelector( href ) ) );
  // remote tab
  // prevent loading the page itself if href is just "#"
  } else if ( href && href !== "#" ) {
@@ -139,7 +139,7 @@ $.widget( "ui.tabs", {
 
  var id = self._tabId( a );
  a.href = "#" + id;
- var $panel = $( "#" + id );
+ var $panel = self.element.find( "#" + id );
  if ( !$panel.length ) {
  $panel = $( o.panelTemplate )
  .attr( "id", id )
@@ -210,13 +210,13 @@ $.widget( "ui.tabs", {
  this.lis.removeClass( "ui-tabs-selected ui-state-active" );
  // check for length avoids error when initializing empty list
  if ( o.selected >= 0 && this.anchors.length ) {
- $( self._sanitizeSelector( self.anchors[ o.selected ].hash ) ).removeClass( "ui-tabs-hide" );
+ self.element.find( self._sanitizeSelector( self.anchors[ o.selected ].hash ) ).removeClass( "ui-tabs-hide" );
  this.lis.eq( o.selected ).addClass( "ui-tabs-selected ui-state-active" );
 
  // seems to be expected behavior that the show callback is fired
  self.element.queue( "tabs", function() {
  self._trigger( "show", null,
- self._ui( self.anchors[ o.selected ], $( self._sanitizeSelector( self.anchors[ o.selected ].hash ) ) ) );
+ self._ui( self.anchors[ o.selected ], self.element.find( self._sanitizeSelector( self.anchors[ o.selected ].hash ) )[ 0 ] ) );
  });
 
  this.load( o.selected );
@@ -337,7 +337,7 @@ $.widget( "ui.tabs", {
  var el = this,
  $li = $(el).closest( "li" ),
  $hide = self.panels.filter( ":not(.ui-tabs-hide)" ),
- $show = $( self._sanitizeSelector( el.hash ) );
+ $show = self.element.find( self._sanitizeSelector( el.hash ) );
 
  // If tab is already selected and not collapsible or tab disabled or
  // or is already loading or click callback returns false stop here.
@@ -496,7 +496,7 @@ $.widget( "ui.tabs", {
  $li.addClass( "ui-state-default ui-corner-top" ).data( "destroy.tabs", true );
 
  // try to find an existing element before creating a new one
- var $panel = $( "#" + id );
+ var $panel = self.element.find( "#" + id );
  if ( !$panel.length ) {
  $panel = $( o.panelTemplate )
  .attr( "id", id )
@@ -630,7 +630,7 @@ $.widget( "ui.tabs", {
  this.xhr = $.ajax( $.extend( {}, o.ajaxOptions, {
  url: url,
  success: function( r, s ) {
- $( self._sanitizeSelector( a.hash ) ).html( r );
+ self.element.find( self._sanitizeSelector( a.hash ) ).html( r );
 
  // take care of tab labels
  self._cleanup();
@@ -698,7 +698,7 @@ $.widget( "ui.tabs", {
 });
 
 $.extend( $.ui.tabs, {
- version: "1.8.6"
+ version: "1.8.11"
 });
 
 /*
@@ -1,7 +1,7 @@
 /*
- * jQuery UI Tabs 1.8.6
+ * jQuery UI Tabs 1.8.11
  *

Modified: ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.widget.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/jackrabbit20100709/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.widget.js?rev=1090153&r1=1090152&r2=1090153&view=diff
==============================================================================